@@ -1,5 +1,5 @@
 import { css } from '@emotion/css';
-import { useEffect, useRef, useState } from 'react';
+import { useCallback, useEffect, useRef, useState } from 'react';
 import { Controller, FormProvider, SubmitHandler, useForm, useFormContext } from 'react-hook-form';
 
 import { ContactPointSelector } from '@grafana/alerting/unstable';
@@ -20,7 +20,7 @@ import {
   useStyles2,
   useTheme2,
 } from '@grafana/ui';
-import { contextSrv } from 'app/core/core';
+import { contextSrv } from 'app/core/services/context_srv';
 import type { AdvancedFilters } from 'app/features/alerting/unified/rule-list/filter/types';
 import { AccessControlAction } from 'app/types/accessControl';
 import { PromAlertingRuleState, PromRuleType } from 'app/types/unified-alerting-dto';
@@ -55,6 +55,25 @@ const canRenderContactPointSelector = contextSrv.hasPermission(AccessControlActi
 
 const radioGroupCompactClass = css({ width: 'max-content' });
 
+// Helper to create a wrapped options function that captures typed input when threshold is exceeded
+function createThresholdAwareOptions<T extends { infoOption?: boolean }>(
+  optionsFunc: (inputValue: string) => Promise<T[]>,
+  setValue: (value: string) => void,
+  fieldName: string
+) {
+  return async (inputValue: string): Promise<T[]> => {
+    const options = await optionsFunc(inputValue);
+    const exceeded = options.length === 1 && options[0].infoOption === true;
+
+    // If threshold exceeded and user is typing, capture the typed value
+    if (exceeded && inputValue) {
+      setValue(inputValue);
+    }
+
+    return options;
+  };
+}
+
 type SearchQueryForm = {
   query: string;
 };
@@ -85,11 +104,9 @@ export default function RulesFilter({ viewMode, onViewModeChange }: RulesFilterP
   };
 
   const handleAdvancedFilters: SubmitHandler<AdvancedFilters> = (values) => {
-    const newFilter = formAdvancedFiltersToRuleFilter(values);
-    updateFilters(newFilter);
-
+    updateFilters(formAdvancedFiltersToRuleFilter(values));
     trackFilterButtonApplyClick(values, pluginsFilterEnabled);
-    setIsPopupOpen(false); // Should close popup after applying filters?
+    setIsPopupOpen(false);
   };
 
   const handleClearFilters = () => {
@@ -248,8 +265,7 @@ const FilterOptions = ({ onSubmit, onClear, pluginsFilterEnabled }: FilterOption
   const defaultValues = searchQueryToDefaultValues(filterState);
 
   // Fetch namespace and group data from all sources (optimized for filter UI)
-  const { namespaceOptions, allGroupNames, isLoadingNamespaces, namespacePlaceholder, groupPlaceholder } =
-    useNamespaceAndGroupOptions();
+  const { namespaceOptions, groupOptions, namespacePlaceholder, groupPlaceholder } = useNamespaceAndGroupOptions();
 
   const { labelOptions } = useLabelOptions();
 
@@ -294,13 +310,11 @@ const FilterOptions = ({ onSubmit, onClear, pluginsFilterEnabled }: FilterOption
             <NamespaceField
               namespaceOptions={namespaceOptions}
               namespacePlaceholder={namespacePlaceholder}
-              isLoadingNamespaces={isLoadingNamespaces}
               portalContainer={portalContainer}
             />
             <GroupField
-              allGroupNames={allGroupNames}
+              groupOptions={groupOptions}
               groupPlaceholder={groupPlaceholder}
-              isLoadingNamespaces={isLoadingNamespaces}
               portalContainer={portalContainer}
             />
             <DataSourceNamesField dataSourceOptions={dataSourceOptions} portalContainer={portalContainer} />
@@ -373,15 +387,22 @@ function LabelsField({
 function NamespaceField({
   namespaceOptions,
   namespacePlaceholder,
-  isLoadingNamespaces,
   portalContainer,
 }: {
-  namespaceOptions: (inputValue: string) => Promise<Array<{ label?: string; value: string; description?: string }>>;
+  namespaceOptions: (
+    inputValue: string
+  ) => Promise<Array<{ label?: string; value: string; description?: string; infoOption?: boolean }>>;
   namespacePlaceholder: string;
-  isLoadingNamespaces: boolean;
   portalContainer?: HTMLElement;
 }) {
-  const { control } = useFormContext<AdvancedFilters>();
+  const { control, setValue } = useFormContext<AdvancedFilters>();
+
+  const wrappedOptions = useCallback(
+    (inputValue: string) =>
+      createThresholdAwareOptions(namespaceOptions, (value) => setValue('namespace', value), 'namespace')(inputValue),
+    [namespaceOptions, setValue]
+  );
+
   return (
     <>
       <Label>
@@ -390,36 +411,36 @@ function NamespaceField({
       <Controller
         name="namespace"
         control={control}
-        render={({ field }) => {
-          return (
-            <Combobox<string>
-              placeholder={namespacePlaceholder}
-              options={namespaceOptions}
-              onChange={(option) => field.onChange(option?.value || null)}
-              value={field.value}
-              loading={isLoadingNamespaces}
-              isClearable
-              portalContainer={portalContainer}
-            />
-          );
-        }}
+        render={({ field }) => (
+          <Combobox<string>
+            placeholder={namespacePlaceholder}
+            options={wrappedOptions}
+            onChange={(option) => {
+              if (!option?.infoOption) {
+                field.onChange(option?.value || null);
+              }
+            }}
+            value={field.value}
+            isClearable
+            portalContainer={portalContainer}
+          />
+        )}
       />
     </>
   );
 }
 
 function GroupField({
-  allGroupNames,
+  groupOptions,
   groupPlaceholder,
-  isLoadingNamespaces,
   portalContainer,
 }: {
-  allGroupNames: string[];
+  groupOptions: (inputValue: string) => Promise<Array<{ label?: string; value: string; infoOption?: boolean }>>;
   groupPlaceholder: string;
-  isLoadingNamespaces: boolean;
   portalContainer?: HTMLElement;
 }) {
   const { control } = useFormContext<AdvancedFilters>();
+
   return (
     <>
       <Label>
@@ -428,19 +449,20 @@ function GroupField({
       <Controller
         name="groupName"
         control={control}
-        render={({ field }) => {
-          return (
-            <Combobox<string>
-              placeholder={groupPlaceholder}
-              options={allGroupNames.map((name) => ({ label: name, value: name }))}
-              onChange={(option) => field.onChange(option?.value || null)}
-              value={field.value}
-              loading={isLoadingNamespaces}
-              isClearable
-              portalContainer={portalContainer}
-            />
-          );
-        }}
+        render={({ field }) => (
+          <Combobox<string>
+            placeholder={groupPlaceholder}
+            options={groupOptions}
+            onChange={(option) => {
+              if (!option?.infoOption) {
+                field.onChange(option?.value || null);
+              }
+            }}
+            value={field.value}
+            isClearable
+            portalContainer={portalContainer}
+          />
+        )}
       />
     </>
   );
@@ -574,7 +596,6 @@ function RuleStateField() {
               { label: t('alerting.rules.state.normal', 'Normal'), value: PromAlertingRuleState.Inactive },
               { label: t('alerting.rules.state.pending', 'Pending'), value: PromAlertingRuleState.Pending },
               { label: t('alerting.rules.state.recovering', 'Recovering'), value: PromAlertingRuleState.Recovering },
-              { label: t('alerting.rules.state.unknown', 'Unknown'), value: PromAlertingRuleState.Unknown },
             ]}
             value={field.value}
             onChange={field.onChange}
@@ -734,7 +755,10 @@ function SearchQueryHelp() {
           title={t('alerting.search-query-help.title-labels', 'Labels')}
           expr='label:team=A label:"cluster=new york"'
         />
-        <HelpRow title={t('alerting.search-query-help.title-state', 'State')} expr="state:firing|normal|pending" />
+        <HelpRow
+          title={t('alerting.search-query-help.title-state', 'State')}
+          expr="state:firing|normal|pending|recovering"
+        />
         <HelpRow title={t('alerting.search-query-help.title-type', 'Type')} expr="type:alerting|recording" />
         <HelpRow title={t('alerting.search-query-help.title-health', 'Health')} expr="health:ok|nodata|error" />
         <HelpRow
