@@ -1,5 +1,11 @@
 import { config } from '@grafana/runtime';
-import { MultiValueVariable, SceneVariables, sceneUtils } from '@grafana/scenes';
+import {
+  AdHocFilterWithLabels as SceneAdHocFilterWithLabels,
+  MultiValueVariable,
+  SceneVariables,
+  sceneUtils,
+  SceneVariable,
+} from '@grafana/scenes';
 import {
   VariableModel,
   VariableRefresh as OldVariableRefresh,
@@ -18,12 +24,18 @@ import {
   GroupByVariableKind,
   defaultVariableHide,
   VariableOption,
-} from '@grafana/schema/dist/esm/schema/dashboard/v2alpha1/types.spec.gen';
+  defaultDataQueryKind,
+  AdHocFilterWithLabels,
+  SwitchVariableKind,
+  defaultIntervalVariableSpec,
+} from '@grafana/schema/dist/esm/schema/dashboard/v2';
+import { getDefaultDatasource } from 'app/features/dashboard/api/ResponseTransformers';
 
 import { getIntervalsQueryFromNewIntervalModel } from '../utils/utils';
 
 import { DSReferencesMapping } from './DashboardSceneSerializer';
-import { getDataQueryKind, getDataQuerySpec, getElementDatasource } from './transformSceneToSaveModelSchemaV2';
+import { getDataSourceForQuery } from './layoutSerializers/utils';
+import { getDataQueryKind, getElementDatasource } from './transformSceneToSaveModelSchemaV2';
 import {
   transformVariableRefreshToEnum,
   transformVariableHideToEnum,
@@ -41,6 +53,7 @@ import {
 
 export function sceneVariablesSetToVariables(set: SceneVariables, keepQueryOptions?: boolean) {
   const variables: VariableModel[] = [];
+
   for (const variable of set.state.variables) {
     const commonProperties = {
       name: variable.state.name,
@@ -53,9 +66,7 @@ export function sceneVariablesSetToVariables(set: SceneVariables, keepQueryOptio
 
     if (sceneUtils.isQueryVariable(variable)) {
       let options: VariableOption[] = [];
-      // Not sure if we actually have to still support this option given
-      // that it's not exposed in the UI
-      if (transformVariableRefreshToEnum(variable.state.refresh) === 'never' || keepQueryOptions) {
+      if (keepQueryOptions) {
         options = variableValueOptionsToVariableOptions(variable.state);
       }
       variables.push({
@@ -78,6 +89,11 @@ export function sceneVariablesSetToVariables(set: SceneVariables, keepQueryOptio
         multi: variable.state.isMulti,
         allowCustomValue: variable.state.allowCustomValue,
         skipUrlSync: variable.state.skipUrlSync,
+        staticOptions: variable.state.staticOptions?.map((option) => ({
+          text: option.label,
+          value: String(option.value),
+        })),
+        staticOptionsOrder: variable.state.staticOptionsOrder,
       });
     } else if (sceneUtils.isCustomVariable(variable)) {
       variables.push({
@@ -88,7 +104,7 @@ export function sceneVariablesSetToVariables(set: SceneVariables, keepQueryOptio
           // @ts-expect-error
           value: variable.state.value,
         },
-        options: variableValueOptionsToVariableOptions(variable.state),
+        options: [],
         query: variable.state.query,
         multi: variable.state.isMulti,
         allValue: variable.state.allValue,
@@ -159,6 +175,14 @@ export function sceneVariablesSetToVariables(set: SceneVariables, keepQueryOptio
         query: variable.state.value,
       });
     } else if (sceneUtils.isGroupByVariable(variable) && config.featureToggles.groupByVariable) {
+      // @ts-expect-error
+      const defaultVariableOption: VariableOption | undefined = variable.state.defaultValue
+        ? {
+            value: variable.state.defaultValue.value,
+            text: variable.state.defaultValue.text,
+          }
+        : undefined;
+
       variables.push({
         ...commonProperties,
         datasource: variable.state.datasource,
@@ -173,6 +197,7 @@ export function sceneVariablesSetToVariables(set: SceneVariables, keepQueryOptio
           // @ts-expect-error
           value: variable.state.value,
         },
+        defaultValue: defaultVariableOption,
         allowCustomValue: variable.state.allowCustomValue,
       });
     } else if (sceneUtils.isAdHocVariable(variable)) {
@@ -181,10 +206,30 @@ export function sceneVariablesSetToVariables(set: SceneVariables, keepQueryOptio
         datasource: variable.state.datasource,
         allowCustomValue: variable.state.allowCustomValue,
         // @ts-expect-error
-        baseFilters: variable.state.baseFilters,
-        filters: variable.state.filters,
+        baseFilters: variable.state.baseFilters || [],
+        filters: [...validateFiltersOrigin(variable.state.originFilters), ...variable.state.filters],
         defaultKeys: variable.state.defaultKeys,
       });
+    } else if (sceneUtils.isSwitchVariable(variable)) {
+      variables.push({
+        ...commonProperties,
+        current: {
+          value: variable.state.value,
+          text: variable.state.value,
+        },
+        options: [
+          {
+            value: variable.state.enabledValue,
+            text: variable.state.enabledValue,
+          },
+          {
+            value: variable.state.disabledValue,
+            text: variable.state.disabledValue,
+          },
+        ],
+      });
+    } else if (variable.state.type === 'system') {
+      // Not persisted
     } else {
       throw new Error('Unsupported variable type');
     }
@@ -237,6 +282,7 @@ export function sceneVariablesSetToSchemaV2Variables(
   | ConstantVariableKind
   | GroupByVariableKind
   | AdhocVariableKind
+  | SwitchVariableKind
 > {
   let variables: Array<
     | QueryVariableKind
@@ -247,6 +293,7 @@ export function sceneVariablesSetToSchemaV2Variables(
     | ConstantVariableKind
     | GroupByVariableKind
     | AdhocVariableKind
+    | SwitchVariableKind
   > = [];
 
   for (const variable of set.state.variables) {
@@ -267,25 +314,44 @@ export function sceneVariablesSetToSchemaV2Variables(
     };
 
     let options: VariableOption[] = [];
+
+    // Query variable
     if (sceneUtils.isQueryVariable(variable)) {
-      // Not sure if we actually have to still support this option given
-      // that it's not exposed in the UI
-      if (transformVariableRefreshToEnum(variable.state.refresh) === 'never' || keepQueryOptions) {
+      if (keepQueryOptions) {
         options = variableValueOptionsToVariableOptions(variable.state);
       }
       const query = variable.state.query;
       let dataQuery: DataQueryKind | string;
+      const datasource = getElementDatasource(set, variable, 'variable', undefined, dsReferencesMapping);
+
       if (typeof query !== 'string') {
         dataQuery = {
-          kind: variable.state.datasource?.type ?? getDataQueryKind(query),
-          spec: getDataQuerySpec(query),
+          kind: 'DataQuery',
+          version: defaultDataQueryKind().version,
+          group: datasource?.type || getDataQueryKind(query),
+          ...(datasource?.uid && {
+            datasource: {
+              name: datasource.uid,
+            },
+          }),
+          spec: query,
         };
       } else {
+        // Only include LEGACY_STRING_VALUE_KEY if query is a non-empty string
+        const spec: Record<string, string> = {};
+        if (query) {
+          spec[LEGACY_STRING_VALUE_KEY] = query;
+        }
         dataQuery = {
-          kind: variable.state.datasource?.type ?? getDataQueryKind(query),
-          spec: {
-            [LEGACY_STRING_VALUE_KEY]: query,
-          },
+          kind: 'DataQuery',
+          version: defaultDataQueryKind().version,
+          group: datasource?.type || getDataQueryKind(query),
+          ...(datasource?.uid && {
+            datasource: {
+              name: datasource.uid,
+            },
+          }),
+          spec,
         };
       }
       const queryVariable: QueryVariableKind = {
@@ -296,32 +362,41 @@ export function sceneVariablesSetToSchemaV2Variables(
           options,
           query: dataQuery,
           definition: variable.state.definition,
-          datasource: getElementDatasource(set, variable, 'variable', undefined, dsReferencesMapping),
           sort: transformSortVariableToEnum(variable.state.sort),
           refresh: transformVariableRefreshToEnum(variable.state.refresh),
-          regex: variable.state.regex,
+          regex: variable.state.regex ?? '',
           allValue: variable.state.allValue,
           includeAll: variable.state.includeAll || false,
           multi: variable.state.isMulti || false,
           skipUrlSync: variable.state.skipUrlSync || false,
+          allowCustomValue: variable.state.allowCustomValue ?? true,
+          staticOptions: variable.state.staticOptions?.map((option) => ({
+            text: option.label,
+            value: String(option.value),
+          })),
+          staticOptionsOrder: variable.state.staticOptionsOrder,
         },
       };
       variables.push(queryVariable);
+
+      // Custom variable
     } else if (sceneUtils.isCustomVariable(variable)) {
-      options = variableValueOptionsToVariableOptions(variable.state);
       const customVariable: CustomVariableKind = {
         kind: 'CustomVariable',
         spec: {
           ...commonProperties,
           current: currentVariableOption,
-          options,
+          options: [],
           query: variable.state.query,
           multi: variable.state.isMulti || false,
           allValue: variable.state.allValue,
           includeAll: variable.state.includeAll ?? false,
+          allowCustomValue: variable.state.allowCustomValue ?? true,
         },
       };
       variables.push(customVariable);
+
+      // Datasource variable
     } else if (sceneUtils.isDataSourceVariable(variable)) {
       const datasourceVariable: DatasourceVariableKind = {
         kind: 'DatasourceVariable',
@@ -329,11 +404,12 @@ export function sceneVariablesSetToSchemaV2Variables(
           ...commonProperties,
           current: currentVariableOption,
           options: [],
-          regex: variable.state.regex,
+          regex: variable.state.regex ?? '',
           refresh: 'onDashboardLoad',
-          pluginId: variable.state.pluginId,
+          pluginId: variable.state.pluginId ?? getDefaultDatasource().type,
           multi: variable.state.isMulti || false,
           includeAll: variable.state.includeAll || false,
+          allowCustomValue: variable.state.allowCustomValue ?? true,
         },
       };
 
@@ -342,21 +418,24 @@ export function sceneVariablesSetToSchemaV2Variables(
       }
 
       variables.push(datasourceVariable);
+
+      // Constant variable
     } else if (sceneUtils.isConstantVariable(variable)) {
+      const value = variable.state.value ? String(variable.state.value) : '';
       const constantVariable: ConstantVariableKind = {
         kind: 'ConstantVariable',
         spec: {
           ...commonProperties,
           current: {
-            ...currentVariableOption,
-            // Constant variable doesn't use text state
-            text: String(variable.state.value),
+            text: value,
+            value: value,
           },
-          // @ts-expect-error
-          query: variable.state.value,
+          query: value,
         },
       };
       variables.push(constantVariable);
+
+      // Interval variable
     } else if (sceneUtils.isIntervalVariable(variable)) {
       const intervals = getIntervalsQueryFromNewIntervalModel(variable.state.intervals);
       const intervalVariable: IntervalVariableKind = {
@@ -369,22 +448,24 @@ export function sceneVariablesSetToSchemaV2Variables(
             text: variable.state.value,
           },
           query: intervals,
-          refresh: 'onTimeRangeChanged',
+          refresh: defaultIntervalVariableSpec().refresh,
           options: variable.state.intervals.map((interval) => ({
             value: interval,
             text: interval,
             selected: interval === variable.state.value,
           })),
-          auto: variable.state.autoEnabled,
-          auto_min: variable.state.autoMinInterval,
-          auto_count: variable.state.autoStepCount,
+          auto: variable.state.autoEnabled ?? defaultIntervalVariableSpec().auto,
+          auto_min: variable.state.autoMinInterval ?? defaultIntervalVariableSpec().auto_min,
+          auto_count: variable.state.autoStepCount ?? defaultIntervalVariableSpec().auto_count,
         },
       };
       variables.push(intervalVariable);
+
+      // Textbox variable
     } else if (sceneUtils.isTextBoxVariable(variable)) {
       const current = {
-        text: variable.state.value,
-        value: variable.state.value,
+        text: variable.state.value ?? '',
+        value: variable.state.value ?? '',
       };
 
       const textBoxVariable: TextVariableKind = {
@@ -392,19 +473,37 @@ export function sceneVariablesSetToSchemaV2Variables(
         spec: {
           ...commonProperties,
           current,
-          query: variable.state.value,
+          query: variable.state.value ?? '',
         },
       };
 
       variables.push(textBoxVariable);
+
+      // Groupby variable
     } else if (sceneUtils.isGroupByVariable(variable) && config.featureToggles.groupByVariable) {
       options = variableValueOptionsToVariableOptions(variable.state);
 
+      // @ts-expect-error
+      const defaultVariableOption: VariableOption | undefined = variable.state.defaultValue
+        ? {
+            value: variable.state.defaultValue.value,
+            text: variable.state.defaultValue.text,
+          }
+        : undefined;
+
+      const ds = getDataSourceForQuery(
+        variable.state.datasource,
+        variable.state.datasource?.type || getDefaultDatasource().type!
+      );
+
       const groupVariable: GroupByVariableKind = {
         kind: 'GroupByVariable',
+        group: ds.type!,
+        datasource: {
+          name: ds.uid,
+        },
         spec: {
           ...commonProperties,
-          datasource: variable.state.datasource || {}, // FIXME what is the default value?,
           // Only persist the statically defined options
           options:
             variable.state.defaultOptions?.map((option) => ({
@@ -412,23 +511,53 @@ export function sceneVariablesSetToSchemaV2Variables(
               value: String(option.value),
             })) || [],
           current: currentVariableOption,
+          defaultValue: defaultVariableOption,
           multi: variable.state.isMulti || false,
         },
       };
       variables.push(groupVariable);
+
+      // Adhoc variable
     } else if (sceneUtils.isAdHocVariable(variable)) {
+      const ds = getDataSourceForQuery(
+        variable.state.datasource,
+        variable.state.datasource?.type || getDefaultDatasource().type!
+      );
       const adhocVariable: AdhocVariableKind = {
         kind: 'AdhocVariable',
+        group: ds.type!,
+        datasource: {
+          name: ds.uid,
+        },
         spec: {
           ...commonProperties,
           name: variable.state.name,
-          datasource: variable.state.datasource || {}, //FIXME what is the default value?
-          baseFilters: variable.state.baseFilters || [],
-          filters: variable.state.filters,
+
+          baseFilters: validateFiltersOrigin(variable.state.baseFilters) || [],
+          filters: [
+            ...validateFiltersOrigin(variable.state.originFilters),
+            ...validateFiltersOrigin(variable.state.filters),
+          ],
           defaultKeys: variable.state.defaultKeys || [], //FIXME what is the default value?
+          allowCustomValue: variable.state.allowCustomValue ?? true,
         },
       };
       variables.push(adhocVariable);
+
+      // Switch variable
+    } else if (sceneUtils.isSwitchVariable(variable)) {
+      const switchVariable: SwitchVariableKind = {
+        kind: 'SwitchVariable',
+        spec: {
+          ...commonProperties,
+          current: variable.state.value,
+          enabledValue: variable.state.enabledValue,
+          disabledValue: variable.state.disabledValue,
+        },
+      };
+      variables.push(switchVariable);
+    } else if (variable.state.type === 'system') {
+      // Do nothing
     } else {
       throw new Error('Unsupported variable type: ' + variable.state.type);
     }
@@ -436,3 +565,12 @@ export function sceneVariablesSetToSchemaV2Variables(
 
   return variables;
 }
+
+export function validateFiltersOrigin(filters?: SceneAdHocFilterWithLabels[]): AdHocFilterWithLabels[] {
+  // Only keep dashboard originated filters in the schema
+  return filters?.filter((f): f is AdHocFilterWithLabels => !f.origin || f.origin === 'dashboard') || [];
+}
+
+export function isVariableEditable(variable: SceneVariable) {
+  return variable.state.type !== 'system';
+}
